Project documentation
#####################

.. raw:: latex

   \setcounter{secnumdepth}{-1}

.. include:: ../../CHANGES.rst

.. include:: ../../CREDITS.rst

.. raw:: latex

   \setcounter{secnumdepth}{2}
